@@ -783,6 +783,7 @@ class Audit:
                 "pywin",
                 "win32ui",
                 "win32uiole",
+                "uploads_management",
             ]
         else:
             preinstall_modules = [
@@ -794,6 +795,7 @@ class Audit:
                 "activate_this",
                 "wsgi",
                 "_distutils_hack",
+                "uploads_management",
             ]
 
         for module in iter_modules():
@@ -1433,8 +1435,8 @@ class Audit:
                 send_mail(
                     configuration,
                     f"Current WebScripts version: {version}\n"
-                    f"Latest WebScripts version:  {latest}\n"
-                    "It is recommended that you upgrade your WebScripts server.",
+                    f"Latest WebScripts version:  {latest}\nIt is "
+                    "recommended that you upgrade your WebScripts server.",
                 )
 
             latest_ = latest
